@@ -22,7 +22,9 @@ int rmdir_main (int argc, char **argv) {
 	}
 
 	for (i=option_recurse;i<(argc-1);i++) {
-	
+/* TODO: Make it actually call rmdir(2) here. */
+		printf("%s\n",argv[i]);
 	}
+
 	return(0);	
 }
